@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  * The Totem project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Totem. This
@@ -413,7 +413,6 @@ static void
 write_directory_listing (TotemBemusedPlugin *tp, GIOChannel *source, gboolean at_root)
 {
 	char *filename;
-	char *root;
 	char buf[2];
 
 	if (at_root == FALSE)
