@@ -49,6 +49,9 @@ G_MODULE_EXPORT gboolean totem_fullscreen_vol_slider_released_cb (GtkWidget *wid
 G_MODULE_EXPORT gboolean totem_fullscreen_seek_slider_pressed_cb (GtkWidget *widget, GdkEventButton *event, TotemFullscreen *fs);
 G_MODULE_EXPORT gboolean totem_fullscreen_seek_slider_released_cb (GtkWidget *widget, GdkEventButton *event, TotemFullscreen *fs);
 G_MODULE_EXPORT gboolean totem_fullscreen_motion_notify (GtkWidget *widget, GdkEventMotion *event, TotemFullscreen *fs);
+G_MODULE_EXPORT gboolean totem_fullscreen_control_enter_notify (GtkWidget *widget, GdkEventCrossing *event, TotemFullscreen *fs);
+G_MODULE_EXPORT gboolean totem_fullscreen_control_leave_notify (GtkWidget *widget, GdkEventCrossing *event, TotemFullscreen *fs);
+
 
 struct _TotemFullscreenPrivate {
 	BaconVideoWidget *bvw;
@@ -63,6 +66,7 @@ struct _TotemFullscreenPrivate {
 
 	guint             popup_timeout;
 	gboolean          popup_in_progress;
+	gboolean          pointer_on_control;
 	guint             motion_handler_id;
 
 	GtkBuilder       *xml;
@@ -206,20 +210,10 @@ totem_fullscreen_set_cursor (TotemFullscreen *fs, gboolean state)
 		bacon_video_widget_set_show_cursor (fs->priv->bvw, state);
 }
 
-static GtkWidget *
-totem_fullscreen_get_volume_popup (TotemFullscreen *fs)
-{
-	return gtk_widget_get_toplevel (GTK_SCALE_BUTTON (fs->volume)->plus_button);
-}
-
 static gboolean
 totem_fullscreen_is_volume_popup_visible (TotemFullscreen *fs)
 {
-	GtkWidget *toplevel;
-
-	/* FIXME we should use the popup-visible property instead */
-	toplevel = totem_fullscreen_get_volume_popup (fs);
-	return GTK_WIDGET_VISIBLE (toplevel);
+	return GTK_WIDGET_VISIBLE (gtk_scale_button_get_popup (GTK_SCALE_BUTTON (fs->volume)));
 }
 
 static void
@@ -255,7 +249,8 @@ G_MODULE_EXPORT gboolean
 totem_fullscreen_motion_notify (GtkWidget *widget, GdkEventMotion *event,
 				TotemFullscreen *fs)
 {
-	totem_fullscreen_show_popups (fs, TRUE);
+	if (!fs->priv->pointer_on_control)
+		totem_fullscreen_show_popups (fs, TRUE);
 	return FALSE;
 }
 
@@ -298,6 +293,25 @@ totem_fullscreen_show_popups (TotemFullscreen *fs, gboolean show_cursor)
 	fs->priv->popup_in_progress = FALSE;
 }
 
+G_MODULE_EXPORT gboolean
+totem_fullscreen_control_enter_notify (GtkWidget *widget,
+			       GdkEventCrossing *event,
+			       TotemFullscreen *fs)
+{
+	fs->priv->pointer_on_control = TRUE;
+	totem_fullscreen_popup_timeout_remove (fs);
+	return TRUE;
+}
+
+G_MODULE_EXPORT gboolean
+totem_fullscreen_control_leave_notify (GtkWidget *widget,
+			       GdkEventCrossing *event,
+			       TotemFullscreen *fs)
+{
+	fs->priv->pointer_on_control = FALSE;
+	return TRUE;
+}
+
 void
 totem_fullscreen_set_fullscreen (TotemFullscreen *fs,
 				 gboolean fullscreen)
@@ -331,7 +345,7 @@ totem_fullscreen_parent_window_notify (GtkWidget *parent_window,
 	if (totem_fullscreen_is_fullscreen (fs) == FALSE)
 		return;
 
-	popup = totem_fullscreen_get_volume_popup (fs);
+	popup = gtk_scale_button_get_popup (GTK_SCALE_BUTTON (fs->volume));
 	if (parent_window == fs->priv->parent_window &&
 	    gtk_window_is_active (GTK_WINDOW (parent_window)) == FALSE &&
 	    GTK_WIDGET_VISIBLE (popup) == FALSE) {
@@ -420,6 +434,8 @@ totem_fullscreen_init (TotemFullscreen *self)
 	if (self->priv->xml == NULL)
 		return;
 
+	self->priv->pointer_on_control = FALSE;
+
 	self->priv->exit_popup = GTK_WIDGET (gtk_builder_get_object (self->priv->xml,
 				"totem_exit_fullscreen_window"));
 	self->priv->control_popup = GTK_WIDGET (gtk_builder_get_object (self->priv->xml,
