@@ -23,17 +23,17 @@
 #ifndef TOTEM_PLAYLIST_H
 #define TOTEM_PLAYLIST_H
 
-#include <gtk/gtkvbox.h>
+#include <gtk/gtk.h>
 #include <totem-pl-parser.h>
 #include <gio/gio.h>
 
 G_BEGIN_DECLS
 
 #define TOTEM_TYPE_PLAYLIST            (totem_playlist_get_type ())
-#define TOTEM_PLAYLIST(obj)            (GTK_CHECK_CAST ((obj), TOTEM_TYPE_PLAYLIST, TotemPlaylist))
-#define TOTEM_PLAYLIST_CLASS(klass)    (GTK_CHECK_CLASS_CAST ((klass), TOTEM_TYPE_PLAYLIST, TotemPlaylistClass))
-#define TOTEM_IS_PLAYLIST(obj)         (GTK_CHECK_TYPE ((obj), TOTEM_TYPE_PLAYLIST))
-#define TOTEM_IS_PLAYLIST_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), TOTEM_TYPE_PLAYLIST))
+#define TOTEM_PLAYLIST(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), TOTEM_TYPE_PLAYLIST, TotemPlaylist))
+#define TOTEM_PLAYLIST_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), TOTEM_TYPE_PLAYLIST, TotemPlaylistClass))
+#define TOTEM_IS_PLAYLIST(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TOTEM_TYPE_PLAYLIST))
+#define TOTEM_IS_PLAYLIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TOTEM_TYPE_PLAYLIST))
 
 typedef enum {
 	TOTEM_PLAYLIST_STATUS_NONE,
@@ -46,6 +46,12 @@ typedef enum {
 	TOTEM_PLAYLIST_DIRECTION_PREVIOUS
 } TotemPlaylistDirection;
 
+typedef enum {
+	TOTEM_PLAYLIST_DIALOG_SELECTED,
+	TOTEM_PLAYLIST_DIALOG_PLAYING
+} TotemPlaylistSelectDialog;
+
+
 typedef struct TotemPlaylist	       TotemPlaylist;
 typedef struct TotemPlaylistClass      TotemPlaylistClass;
 typedef struct TotemPlaylistPrivate    TotemPlaylistPrivate;
@@ -74,7 +80,7 @@ struct TotemPlaylistClass {
 	void (*item_removed) (TotemPlaylist *playlist, const gchar *filename, const gchar *uri);
 };
 
-GtkType    totem_playlist_get_type (void);
+GType    totem_playlist_get_type (void);
 GtkWidget *totem_playlist_new      (void);
 
 /* The application is responsible for checking that the mrl is correct
@@ -92,6 +98,8 @@ void totem_playlist_save_current_playlist (TotemPlaylist *playlist,
 					   const char *output);
 void totem_playlist_save_current_playlist_ext (TotemPlaylist *playlist,
 					   const char *output, TotemPlParserType type);
+void totem_playlist_select_subtitle_dialog (TotemPlaylist *playlist,
+					    TotemPlaylistSelectDialog mode);
 
 /* totem_playlist_clear doesn't emit the current_removed signal, even if it does
  * because the caller should know what to do after it's done with clearing */
@@ -103,15 +111,13 @@ char      *totem_playlist_get_current_mrl (TotemPlaylist *playlist,
 char      *totem_playlist_get_current_title (TotemPlaylist *playlist,
 					     gboolean *custom);
 char      *totem_playlist_get_title (TotemPlaylist *playlist,
-				     guint index);
+				     guint title_index);
 
-gboolean   totem_playlist_get_current_metadata (TotemPlaylist *playlist,
-						char         **artist,
-						char         **title,
-						char         **album);
 gboolean   totem_playlist_set_title (TotemPlaylist *playlist,
 				     const char *title,
 				     gboolean force);
+void       totem_playlist_set_current_subtitle (TotemPlaylist *playlist,
+						const char *subtitle_uri);
 
 #define    totem_playlist_has_direction(playlist, direction) (direction == TOTEM_PLAYLIST_DIRECTION_NEXT ? totem_playlist_has_next_mrl (playlist) : totem_playlist_has_previous_mrl (playlist))
 gboolean   totem_playlist_has_previous_mrl (TotemPlaylist *playlist);
@@ -134,9 +140,9 @@ TotemPlaylistStatus totem_playlist_get_playing (TotemPlaylist *playlist);
 void       totem_playlist_set_at_start (TotemPlaylist *playlist);
 void       totem_playlist_set_at_end (TotemPlaylist *playlist);
 
-guint      totem_playlist_get_current (TotemPlaylist *playlist);
-guint      totem_playlist_get_last (TotemPlaylist *playlist);
-void       totem_playlist_set_current (TotemPlaylist *playlist, guint index);
+int        totem_playlist_get_current (TotemPlaylist *playlist);
+int        totem_playlist_get_last (TotemPlaylist *playlist);
+void       totem_playlist_set_current (TotemPlaylist *playlist, guint current_index);
 
 void       totem_playlist_foreach (TotemPlaylist *playlist,
 				   TotemPlaylistForeachFunc callback,
